@@ -3,20 +3,33 @@ from testutil import *
 
 import os
 
-from evase.structures.projectstructure import ProjectAnalysisStruct, dir_to_module_structure
+from evase.structures.projectstructure import dir_to_module_structure
 
 
 class TestProjectAnalysisStruct(unittest.TestCase):
+    """
+    Tests the functionality of the project structure object.
+    """
 
     def setUp(self):
-        self.test_struct1 = ProjectAnalysisStruct("test1", prjroot1_filename)
+        """
+        Set up project structure.
+        """
+        self.test_struct1 = get_projectstruct("test1", prjroot1_filename)
 
     def test_project_root(self):
-        self.assertEqual(prjroot1_filename, self.test_struct1.get_prj_root())
+        """
+        Test the root of the structure.
+        """
+
+        self.assertEqual(prjroot1_filename, self.test_struct1.root)
 
     def test_project_struct_dirs(self):
+        """
+        Test the ability to make the module structure.
+        """
 
-        md_struct = self.test_struct1.get_module_structure()
+        md_struct = self.test_struct1.structure
 
         total_len = 0
         for root, dirs, files in os.walk(prjroot1_filename):
@@ -37,7 +50,3 @@ class TestProjectAnalysisStruct(unittest.TestCase):
         self.assertIn('prjstructtest.util.moreutil.helper2', test_mdl_struct)
         self.assertIn('prjstructtest.util.moreutil.__init__', test_mdl_struct)
 
-    def test_other(self):
-        for mdl in self.test_struct1.get_module_structure().values():
-            print(mdl.get_module_imports())
-            print(mdl.get_local_imports())
